%define major         1
%define libname       %mklibname %{name} %major
%define libname_devel %mklibname %{name} -d

Summary:        The free/open-source library for quantitative finance
Name:           quantlib
Version:        1.37
Release:        %mkrel 1
License:        BSD License
Group:          System/Libraries
URL:            https://www.quantlib.org/
Source0:        https://github.com/lballabio/QuantLib/releases/download/v%{version}/QuantLib-%{version}.tar.gz
Patch1:         Quantlib-1.28-lib-path.patch
Patch2:         Quantlib-1.35-pkgconfig-location.patch
BuildRequires:  boost-devel
BuildRequires:  doxygen
BuildRequires:  graphviz
# Needed to create elisp files
BuildRequires:  emacs
BuildRequires:  libgomp-devel
BuildRequires:  ninja
BuildRequires:  cmake

%description
QuantLib is an open source C++ library for financial quantitative analysts
and developers.

%package -n %libname
Summary:        Shared library for QuantLib
Group:          System/Libraries
Obsoletes:      %{_lib}quantlib1 < 1.2.1-3
Provides:       quantlib = %{version}-%{release}

%description -n %libname
QuantLib is an open source C++ library for financial quantitative analysts
and developers.

Install %{libname} if you are going are using shared libraries with
QuantLib.

%package -n %libname_devel
Summary:        The header files and the static library
Group:          Development/C
Requires:       %libname = %{version}-%{release}
Provides:       quantlib-devel = %{version}-%{release}
Requires:       boost-devel
Conflicts:      %{_lib}quantlib1 < 1.35-2

%description -n %libname_devel
QuantLib is an open source C++ library for financial quantitative analysts
and developers.

Install %{libname_devel} if you are going to develop programs which
will use the QuantLib C++ libraries.

This package contains the intraday patches from the github repo
https://github.com/joequant/quantlib

%package test-suite
Summary:        The test-suite to check the setup of quantlib installation
Group:          System/Libraries

%description test-suite
QuantLib is an open source C++ library for financial quantitative analysts
and developers.

The QuantLib-test-suite will validate the compiled code against
pre-constructed test cases, and helps in validating the library.


%prep
%autosetup -p1 -n QuantLib-%{version}

%build
%cmake -G Ninja \
    -DQL_ENABLE_OPENMP=ON
%cmake_build

# make documentations
# no more valid option
# make_build docs-all -C Docs

%install
%cmake_install

%files -n %libname
%license LICENSE.TXT
%{_libdir}/libQuantLib.so.%{major}{,.*}

%files -n %libname_devel
%doc ChangeLog.txt README.md Contributors.txt News.md
%{_includedir}/ql/
%{_libdir}/cmake/QuantLib/
%{_libdir}/libQuantLib.so
%{_libdir}/pkgconfig/quantlib.pc
%{_bindir}/quantlib-config

%files test-suite
%{_bindir}/quantlib-test-suite
%{_bindir}/quantlib-benchmark
%dir %{_libdir}/QuantLib
%dir %{_libdir}/QuantLib/examples
%{_libdir}/QuantLib/examples/BasketLosses
%{_libdir}/QuantLib/examples/BermudanSwaption
%{_libdir}/QuantLib/examples/Bonds
%{_libdir}/QuantLib/examples/CDS
%{_libdir}/QuantLib/examples/CVAIRS
%{_libdir}/QuantLib/examples/CallableBonds
%{_libdir}/QuantLib/examples/ConvertibleBonds
%{_libdir}/QuantLib/examples/DiscreteHedging
%{_libdir}/QuantLib/examples/EquityOption
%{_libdir}/QuantLib/examples/FRA
%{_libdir}/QuantLib/examples/FittedBondCurve
%{_libdir}/QuantLib/examples/Gaussian1dModels
%{_libdir}/QuantLib/examples/GlobalOptimizer
%{_libdir}/QuantLib/examples/LatentModel
%{_libdir}/QuantLib/examples/MarketModels
%{_libdir}/QuantLib/examples/MulticurveBootstrapping
%{_libdir}/QuantLib/examples/MultidimIntegral
%{_libdir}/QuantLib/examples/Replication
%{_libdir}/QuantLib/examples/Repo


%changelog
* Sat Jan 25 2025 daviddavid <daviddavid> 1.37-1.mga10
+ Revision: 2142093
- new version: 1.37

* Wed Dec 04 2024 daviddavid <daviddavid> 1.36-1.mga10
+ Revision: 2121485
- new version: 1.36

* Sun Aug 18 2024 wally <wally> 1.35-2.mga10
+ Revision: 2086943
- move quantlib-config to devel pkg
- own CMake configuration dir
- add patch to fix pkgconfig .pc location
- use our CMake build flags

* Sun Aug 18 2024 papoteur <papoteur> 1.35-1.mga10
+ Revision: 2086931
- new version 1.35

* Tue Mar 05 2024 papoteur <papoteur> 1.33-1.mga10
+ Revision: 2047696
- new version 1.33

* Fri Jan 05 2024 papoteur <papoteur> 1.32-1.mga10
+ Revision: 2027809
- new version 1.32

* Wed Dec 07 2022 papoteur <papoteur> 1.28-1.mga9
+ Revision: 1919038
- new 1.28
- build with cmake
- remove doc package, no option in cmake to build documentation

* Sun Jul 03 2022 wally <wally> 1.20-8.mga9
+ Revision: 1867306
- rebuild for boost 1.79.0

* Thu Mar 31 2022 umeabot <umeabot> 1.20-7.mga9
+ Revision: 1837142
- Mageia 9 Mass Rebuild

* Sun Dec 19 2021 wally <wally> 1.20-6.mga9
+ Revision: 1762669
- rebuild for boost 1.78.0

* Thu Sep 09 2021 wally <wally> 1.20-5.mga9
+ Revision: 1744635
- rebuild for boost 1.77.0

* Fri May 14 2021 wally <wally> 1.20-4.mga9
+ Revision: 1723013
- rebuild for boost 1.76.0

* Thu Dec 31 2020 wally <wally> 1.20-3.mga8
+ Revision: 1666812
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.20-2.mga8
+ Revision: 1662054
- rebuild for boost 1.74.0

* Mon Nov 16 2020 joequant <joequant> 1.20-1.mga8
+ Revision: 1646582
- update to 1.20

* Sun Jul 26 2020 joequant <joequant> 1.19-4.mga8
+ Revision: 1609106
- tag with release

* Sun Jul 26 2020 joequant <joequant> 1.19-3.mga8
+ Revision: 1609021
- rebuild with std classes

* Sat Jul 25 2020 joequant <joequant> 1.19-2.mga8
+ Revision: 1608991
- revert to use boost::shared_ptr

* Sat Jul 25 2020 joequant <joequant> 1.19-1.mga8
+ Revision: 1608990
- update to 1.19

* Wed Jul 22 2020 joequant <joequant> 1.18-2.mga8
+ Revision: 1607747
- move out doc and fix deps

* Sat Jul 18 2020 joequant <joequant> 1.18-1.mga8
+ Revision: 1607168
- update to 1.18

* Sun May 03 2020 wally <wally> 1.16-4.mga8
+ Revision: 1578107
- rebuild for boost 1.73.0
+ danf <danf>
- Switch URLs from http: to https:

* Wed Feb 19 2020 umeabot <umeabot> 1.16-3.mga8
+ Revision: 1544888
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.16-2.mga8
+ Revision: 1483427
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x

* Mon Sep 23 2019 tv <tv> 1.16-1.mga8
+ Revision: 1444943
- new release

* Tue Oct 16 2018 wally <wally> 1.13-3.mga8
+ Revision: 1321091
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 1.13-2.mga7
+ Revision: 1300746
- Mageia 7 Mass Rebuild

* Fri Jul 27 2018 wally <wally> 1.13-1.mga7
+ Revision: 1245540
- new version 1.13

* Mon Dec 25 2017 wally <wally> 1.10.1-2.mga7
+ Revision: 1184768
- rebuild for new boost

* Wed Nov 22 2017 tv <tv> 1.10.1-1.mga7
+ Revision: 1178626
- drop merged patch
- new release
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1.6.2-3.mga7
+ Revision: 1154549
- rebuild with latest boost

* Sun Dec 27 2015 daviddavid <daviddavid> 1.6.2-2.mga6
+ Revision: 916089
- rebuild for new boost 1.60.0

* Tue Sep 29 2015 fwang <fwang> 1.6.2-1.mga6
+ Revision: 884917
- 1.6.2
- rebuild for new boost

* Thu Aug 27 2015 cjw <cjw> 1.6-3.mga6
+ Revision: 870148
- rebuild with gcc 5

* Sun Aug 02 2015 daviddavid <daviddavid> 1.6-2.mga6
+ Revision: 860626
- rebuild for new boost-1.58.0

* Tue Jun 30 2015 joequant <joequant> 1.6-1.mga6
+ Revision: 848341
- upgrade to 1.6
- update to 1.6

* Sat Apr 04 2015 joequant <joequant> 1.5-2.mga6
+ Revision: 819704
- fix svn script
- fix git
- add git versions
- create export libraries
- checkin intraday patch
- sync with intraday

* Fri Mar 06 2015 joequant <joequant> 1.5-2.mga5
+ Revision: 817907
- remove redundant strike check
- add bitcoin patches

* Tue Feb 03 2015 joequant <joequant> 1.5-1.mga5
+ Revision: 813125
- bump to 1.5

* Thu Jan 15 2015 joequant <joequant> 1.4.1-2.mga5
+ Revision: 810831
- add continuoustime.cpp
- add continoustime.hpp
- new intraday patch

* Tue Dec 23 2014 joequant <joequant> 1.4.1-1.mga5
+ Revision: 805047
- add emacs to depends
- add Makefile.am
- add intraday patches
- add source file
- upgrade to 1.4.1

* Wed Oct 15 2014 umeabot <umeabot> 1.3-5.mga5
+ Revision: 742722
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3-4.mga5
+ Revision: 688575
- Mageia 5 Mass Rebuild

* Sat Feb 08 2014 barjac <barjac> 1.3-3.mga5
+ Revision: 586855
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.3-2.mga4
+ Revision: 530733
- Mageia 4 Mass Rebuild

* Sun Jul 28 2013 joequant <joequant> 1.3-1.mga4
+ Revision: 459402
- remove emacs lisp missing in 1.3
- upgrade to 1.3

* Wed Jul 10 2013 fwang <fwang> 1.2.1-6.mga4
+ Revision: 452508
- rebuild for new boost

* Thu Apr 11 2013 neoclust <neoclust> 1.2.1-5.mga3
+ Revision: 409776
- Rebuild against new boost

* Sun Jan 13 2013 umeabot <umeabot> 1.2.1-4.mga3
+ Revision: 380095
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.2.1-3.mga3
+ Revision: 333277
- correct libname

* Thu Dec 20 2012 fwang <fwang> 1.2.1-2.mga3
+ Revision: 333092
- rebuild for new boost

* Thu Dec 13 2012 neoclust <neoclust> 1.2.1-1.mga3
+ Revision: 330328
- Remove requires in lib in test-suite ( already done by rpm )
  Use rpm macros
  Fix file list
+ joequant <joequant>
- more spec cleanups
- Update to 1.2.1
  Remove unnecessary build and build-requires
- lower case quantlib
  remove unneeded spec commands
- make quantlib lowercase to conform to naming conventions
- imported package QuantLib

